# BEGIN SourceDeps(oneline):
BuildRequires(pre): rpm-macros-fedora-compat
BuildRequires: gcc-c++
# END SourceDeps(oneline)
%global WTSRVDIR        /var/spool/wt
%global WTRUNDIR        %{WTSRVDIR}/run

%global WTRUNUSER       apache
%global WTRUNGROUP      apache

Name:           wt
Version:        3.2.3
Release:        alt1_2
Summary:        C++ library for developing web applications

Group:          Development/Perl
# For a breakdown of the licensing, see PACKAGE-LICENSING
License:        GPLv2 and Boost and MIT and (Boost or MIT) and BSD and zlib
URL:            http://www.webtoolkit.eu/wt
# Following archive was made from upstream tarball downloaded from
#  http://citylan.dl.sourceforge.net/project/witty/wt/3.2.3/wt-3.2.3.tar.gz
# by running generate-tarball.sh 3.2.3 from tarball's directory
Source0:        %{name}-%{version}-free.tar.gz
Source1:        %{name}-%{version}-PACKAGE-LICENSING
# wt toolkit contains bundled non-free library (IBPP) that we cannot ship.
# Therefore we use this script to remove its code before shipping it.
# Download the upstream tarball and invoke this script while in the
# tarball's directory:
#   sh wt-generate-tarball.sh UPSTREAM_VERSION
Source2:        wt-generate-tarball.sh

BuildRequires: ctest cmake boost-devel boost-filesystem-devel boost-wave-devel boost-graph-parallel-devel boost-math-devel boost-mpi-devel boost-program_options-devel boost-signals-devel boost-intrusive-devel boost-asio-devel libssl-devel
BuildRequires:  libGraphicsMagick-devel pango-devel libsqlite3-devel postgresql-devel
BuildRequires:  libharu-devel libfcgi-devel zlib-devel qt4-devel
Source44: import.info

%description
Web C++ library with widget oriented API that uses well-tested patterns of
desktop GUI development tailored to the web. To the developer, it offers
abstraction of web-specific implementation details, including client-server
protocols, event handling, graphics support, graceful degradation (or
progressive enhancement), and URL handling.

%package        dbo
Summary:        Wt::Dbo ORM library and Sqlite3 back-end
Group:          Development/Perl

%description    dbo
This package contains the Wt::Dbo Object-Relational Mapping library
and Sqlite3 back-end of it.

%package        dbo-postgres
Summary:        PostgreSQL back-end for the Wt::Dbo ORM library
Group:          Development/Perl
Requires:       %{name}-dbo%{?_isa} = %{version}-%{release}

%description    dbo-postgres
This package contains the PostgresSQL back-end for the Wt::Dbo ORM library.
 
%package        devel
Summary:        Libraries and header files for witty web development
Group:          Development/Perl
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-dbo%{?_isa} = %{version}-%{release}
Requires:       %{name}-dbo-postgres%{?_isa} = %{version}-%{release}
Requires: ctest cmake

%description    devel
This package contains the files necessary to develop
applications using the Wt toolkit and the Wt::Dbo ORM library.

%package        examples
Summary:        Examples for Wt
Group:          Development/Perl
License:        GPLv2 and MIT
Requires:       %{name}%{?_isa} = %{version}-%{release}
Requires:       %{name}-dbo%{?_isa} = %{version}-%{release}

%description    examples
This package contains programming examples distributed with official Wt
release.

%package        doc
Summary:        Documents for the Wt toolkit
Group:          Documentation
BuildArch:      noarch

%description    doc
This package contains the documents for Wt API and examples.

%prep
%setup -q -n %{name}-%{version}
for d in src resources examples; do
    find $d -type f \( -iregex '.*\.\([hc]\|js\|css\)' -o -executable \) | \
        xargs -r chmod -v 0644
done
find examples -type f -name .htaccess | while read f; do
    mv -v $f `dirname $f`/htaccess
done
# conversion to UTF-8
convdir=`mktemp -d`
for f in examples/style/CornerImage.h; do
    tmpf=${convdir}/`basename $f`
    iconv -f iso-8859-2 -t UTF-8 $f >$tmpf
    mv $tmpf $f
done
rmdir $convdir

%build
mkdir wt-build
cd wt-build
## wtdbofirebird library bundles IBPP c++ client library for firebird
## that is licensed under IBPP License, which is marked as Non-Free
## by Red Hat Legal
## let's not package it, until licensing issues are solved
%{fedora_cmake} .. \
    -DCONNECTOR_HTTP=ON \
    -DCONNECTOR_FCGI=ON \
    -DUSE_SYSTEM_SQLITE3=ON \
    -DWEBUSER="%{WTRUNUSER}" \
    -DWEBGROUP="%{WTRUNGROUP}" \
    -DRUNDIR="%{WTRUNDIR}" \
    -DINSTALL_EXAMPLES=ON \
    -DENABLE_FIREBIRD=OFF \
    -DEXAMPLES_DESTINATION=%{_lib}/Wt/examples
make %{?_smp_mflags}

%install
pushd wt-build
make install DESTDIR=$RPM_BUILD_ROOT
install -v -m 0755 -d ${RPM_BUILD_ROOT}/%{_sysconfdir}/%{name}
cp -v wt_config.xml ${RPM_BUILD_ROOT}/%{_sysconfdir}/%{name}

# makes an absolute symlink to resources directory
make_rsc_link() {
    ln -vs "%{_datadir}/Wt/resources" \
        "${RPM_BUILD_ROOT}%{_libdir}/Wt/examples/$1"
}

# installation of examples
pushd examples
for d in `find . -maxdepth 1 -mindepth 1 -type d | \
        grep -v '^\(CMakeFiles\|feature\)$'`; do
    # create a symlink for each example pointing on resources dir
    make_rsc_link $d
done
for d in `find feature -maxdepth 1 -mindepth 1 -type d | grep -v 'CMakeFiles'`;
do  # create a symlink for each feature example pointing on resources dir
    make_rsc_link $d
done
popd # examples
popd # wt-build

# installation of documentation
for d in %{name} %{name}-dbo %{name}-doc; do
    install -v -m 0755 -d ${RPM_BUILD_ROOT}%{_defaultdocdir}/$d-%{version}/
    cp -v LICENSE ${RPM_BUILD_ROOT}%{_defaultdocdir}/$d-%{version}/
    install -vm 644  %{SOURCE1} \
    ${RPM_BUILD_ROOT}%{_defaultdocdir}/$d-%{version}/PACKAGE-LICENSING
done
cp -vr README.md ReleaseNotes.html Changelog \
    ${RPM_BUILD_ROOT}%{_defaultdocdir}/%{name}-%{version}/
cp -vr INSTALL*.html doc/* ${RPM_BUILD_ROOT}%{_defaultdocdir}/%{name}-doc-%{version}/

pushd ${RPM_BUILD_ROOT}
mkdir -vp .%{WTSRVDIR}
mkdir -vp .%{WTRUNDIR}
install -v -m 0755 -d .%{_datadir}/cmake/Modules
mv -v .%{_prefix}/cmake/*.cmake .%{_datadir}/cmake/Modules

# cleanup
rm -rfv ${_prefix}/cmake
for d in examples reference; do
    rm -v .%{_defaultdocdir}/%{name}-doc-%{version}/$d/html/installdox
done
rm -v .%{_defaultdocdir}/%{name}-doc-%{version}/main
find .%{_libdir}/Wt/examples -regex '.*/\(CMakeFiles\|.*\.cmake\|Doxygen\)' | \
    xargs rm -rfv
# these scripts were used to generate pictures
find .%{_datadir}/Wt/resources -name 'generate.sh' | xargs rm -v
popd

%files
%config(noreplace) %{_sysconfdir}/%{name}/wt_config.xml
%{_libdir}/libwt.so.*
%{_libdir}/libwtext.so.*
%{_libdir}/libwtfcgi.so.*
%{_libdir}/libwthttp.so.*
%{_libdir}/libwttest.so.*
%dir %{_defaultdocdir}/%{name}-%{version}
%doc %{_defaultdocdir}/%{name}-%{version}/README.md
%doc %{_defaultdocdir}/%{name}-%{version}/LICENSE
%doc %{_defaultdocdir}/%{name}-%{version}/ReleaseNotes.html
%doc %{_defaultdocdir}/%{name}-%{version}/Changelog
%doc %{_defaultdocdir}/%{name}-%{version}/PACKAGE-LICENSING
%dir %{_datadir}/Wt
%dir %{_datadir}/Wt/resources
%{_datadir}/Wt/resources/*
%dir %{WTSRVDIR}
%dir %{WTRUNDIR}

%files dbo
%dir %{_defaultdocdir}/%{name}-dbo-%{version}
%doc %{_defaultdocdir}/%{name}-dbo-%{version}/LICENSE
%doc %{_defaultdocdir}/%{name}-dbo-%{version}/PACKAGE-LICENSING
%{_libdir}/libwtdbo.so.*
%{_libdir}/libwtdbosqlite3.so.*

%files dbo-postgres
%{_libdir}/libwtdbopostgres.so.*

%files devel
# header files
%dir %{_includedir}/Wt
%{_includedir}/Wt/*
%{_libdir}/*.so
%{_datadir}/cmake/Modules/*.cmake

%files examples
%dir %{_libdir}/Wt
%dir %{_libdir}/Wt/examples
%{_libdir}/Wt/examples/*

%files doc
%dir %{_defaultdocdir}/%{name}-doc-%{version}
%doc %{_defaultdocdir}/%{name}-doc-%{version}/LICENSE
%doc %{_defaultdocdir}/%{name}-doc-%{version}/PACKAGE-LICENSING
%{_defaultdocdir}/%{name}-doc-%{version}/*.html
%dir %{_defaultdocdir}/%{name}-doc-%{version}/images
%dir %{_defaultdocdir}/%{name}-doc-%{version}/reference
%dir %{_defaultdocdir}/%{name}-doc-%{version}/tutorial
%dir %{_defaultdocdir}/%{name}-doc-%{version}/examples
%{_defaultdocdir}/%{name}-doc-%{version}/images/*
%{_defaultdocdir}/%{name}-doc-%{version}/reference/*
%{_defaultdocdir}/%{name}-doc-%{version}/tutorial/*
%{_defaultdocdir}/%{name}-doc-%{version}/examples/*

%changelog
* Wed Feb 13 2013 Igor Vlasenko <viy@altlinux.ru> 3.2.3-alt1_2
- update to new release by fcimport

* Wed Jan 02 2013 Igor Vlasenko <viy@altlinux.ru> 3.2.3-alt1_1
- update to new release by fcimport

* Wed Oct 10 2012 Igor Vlasenko <viy@altlinux.ru> 3.2.2-alt1_6.p1
- new version

* Wed Aug 15 2012 Igor Vlasenko <viy@altlinux.ru> 3.2.0-alt1_1.R
- new version

